@@ -539,7 +539,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     for (i in seq(along.with = args))
         body[[i+2]] <- as.symbol(args[i])
 
-    body[[1L]] <- .Call
+    body[[1L]] <- quote(.Call)
     body[[2L]] <- getNativeSymbolInfo(symbol, dll)$address
 
     if (isVoid)
@@ -714,7 +714,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     # set CLINK_CPPFLAGS based on the LinkingTo dependencies
     buildEnv$CLINK_CPPFLAGS <- .buildClinkCppFlags(linkingToPackages)
 
-    # add the source file's directory to the compliation
+    # add the source file's directory to the compilation
     srcDir <- dirname(sourceFile)
     srcDir <- asBuildPath(srcDir)
     buildDirs <- srcDir
