@@ -1,4 +1,4 @@
-# Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -20,22 +20,10 @@ Rcpp.system.file <- function(...){
     tools::file_path_as_absolute( base::system.file( ..., package = "Rcpp" ) )
 }
 
-## identifies if the default linking on the platform should be static
-## or dynamic. Currently only linux uses dynamic linking by default
-## although it works fine on mac osx as well
-staticLinking <- function() {
-    ! grepl( "^linux", R.version$os )
-}
-
 ## Use R's internal knowledge of path settings to find the lib/ directory
 ## plus optinally an arch-specific directory on system building multi-arch
 RcppLdPath <- function() {
-    if (nzchar(.Platform$r_arch)) {	## eg amd64, ia64, mips
-        path <- Rcpp.system.file("lib",.Platform$r_arch)
-    } else {
-        path <- Rcpp.system.file("lib")
-    }
-    path
+    ""
 }
 
 ## Provide linker flags -- i.e. -L/path/to/libRcpp -- as well as an
@@ -45,25 +33,11 @@ RcppLdPath <- function() {
 ## Updated Jan 2010:  We now default to static linking but allow the use
 ##                    of rpath on Linux if static==FALSE has been chosen
 ##                    Note that this is probably being called from LdFlags()
-RcppLdFlags <- function(static=staticLinking()) {
-    rcppdir <- RcppLdPath()
-    if (static) {                               # static is default on Windows and OS X
-        flags <- paste(rcppdir, "/libRcpp.a", sep="")
-        if (.Platform$OS.type=="windows") {
-            flags <- asBuildPath(flags)
-        }
-    } else {					# else for dynamic linking
-        flags <- paste("-L", rcppdir, " -lRcpp", sep="") # baseline setting
-        if ((.Platform$OS.type == "unix") &&    # on Linux, we can use rpath to encode path
-            (length(grep("^linux",R.version$os)))) {
-            flags <- paste(flags, " -Wl,-rpath,", rcppdir, sep="")
-        }
-    }
-    invisible(flags)
-}
+## Updated Nov 2013:  We no longer build a library. This should be deprecated. 
+RcppLdFlags <- function() { "" }
 
 # indicates if Rcpp was compiled with GCC >= 4.3
-canUseCXX0X <- function() .Call( "canUseCXX0X", PACKAGE = "Rcpp" )
+canUseCXX0X <- function() { TRUE }  # .Call( "canUseCXX0X", PACKAGE = "Rcpp" )
 
 ## Provide compiler flags -- i.e. -I/path/to/Rcpp.h
 RcppCxxFlags <- function(cxx0x=FALSE) {
@@ -72,7 +46,7 @@ RcppCxxFlags <- function(cxx0x=FALSE) {
     if (.Platform$OS.type=="windows") {
         path <- asBuildPath(path)
     }
-    paste("-I", path, if( cxx0x && canUseCXX0X() ) " -std=c++0x" else "", sep="")
+    paste("-I", path, if (cxx0x && canUseCXX0X()) " -std=c++0x" else "", sep="")
 }
 
 ## Shorter names, and call cat() directly
@@ -81,8 +55,8 @@ CxxFlags <- function(cxx0x=FALSE) {
     cat(RcppCxxFlags(cxx0x=cxx0x))
 }
 ## LdFlags defaults to static linking on the non-Linux platforms Windows and OS X
-LdFlags <- function(static=staticLinking()) {
-    cat(RcppLdFlags(static=static))
+LdFlags <- function() {
+    cat(RcppLdFlags())
 }
 
 # capabilities
